@@ -1,42 +1,35 @@
 #![no_std]
-#![allow(clippy::doc_markdown)]
-#![allow(clippy::inline_always)]
-#![allow(clippy::match_bool)]
-#![allow(incomplete_features)]
-#![feature(const_compare_raw_pointers)]
-#![feature(const_fn)]
-#![feature(const_fn_union)]
-#![feature(const_generics)]
-#![feature(const_if_match)]
-#![feature(const_loop)]
-#![feature(const_mut_refs)]
-#![feature(const_panic)]
-#![feature(const_ptr_offset_from)]
-#![feature(const_raw_ptr_deref)]
-#![feature(const_raw_ptr_to_usize_cast)]
-#![feature(core_intrinsics)]
-#![feature(doc_cfg)]
-#![feature(exact_size_is_empty)]
-#![feature(maybe_uninit_extra)]
-#![feature(maybe_uninit_ref)]
-#![feature(maybe_uninit_uninit_array)]
+#![allow(
+  clippy::doc_markdown,
+  clippy::inline_always,
+  clippy::match_bool,
+  incomplete_features
+)]
+#![feature(
+  const_compare_raw_pointers,
+  const_fn,
+  const_fn_union,
+  const_generics,
+  const_if_match,
+  const_loop,
+  const_mut_refs,
+  const_panic,
+  const_ptr_offset_from,
+  const_raw_ptr_deref,
+  const_raw_ptr_to_usize_cast,
+  core_intrinsics,
+  doc_cfg,
+  exact_size_is_empty,
+  maybe_uninit_extra,
+  maybe_uninit_ref,
+  maybe_uninit_uninit_array,
+  slice_partition_dedup,
+  specialization,
+  trusted_len,
+  untagged_unions
+)]
 #![cfg_attr(feature = "std", feature(read_initializer))]
-#![feature(slice_partition_dedup)]
-#![feature(specialization)]
-#![feature(trusted_len)]
-#![feature(untagged_unions)]
 
-pub use crate::errors::{CapacityError, PushCapacityError};
-pub use crate::heap::{
-  StaticHeap, StaticHeapDrain, StaticHeapDrainSorted, StaticHeapIntoIter, StaticHeapIter,
-  StaticHeapPeekMut,
-};
-pub use crate::iterators::*;
-pub use crate::string::{string_utils, StaticString, StringError};
-use crate::utils::{
-  is_null_const, is_null_mut, quicksort_internal, reverse_copy, slice_from_raw_parts,
-  slice_from_raw_parts_mut,
-};
 use core::cmp::{Ord, PartialEq};
 use core::intrinsics;
 #[doc(hidden)]
@@ -48,6 +41,17 @@ use core::ops::{
 };
 use core::ptr;
 
+pub use crate::errors::{CapacityError, PushCapacityError};
+pub use crate::heap::{
+  StaticHeap, StaticHeapDrainSorted, StaticHeapIntoIterSorted, StaticHeapPeekMut,
+};
+pub use crate::iterators::*;
+pub use crate::string::{string_utils, StaticString, StringError};
+use crate::utils::{
+  is_null_const, is_null_mut, quicksort_internal, reverse_copy, slice_from_raw_parts,
+  slice_from_raw_parts_mut,
+};
+
 #[doc(hidden)]
 pub use staticsort::staticsort as __staticsort;
 
@@ -227,6 +231,14 @@ impl<T, const N: usize> StaticVec<T, N> {
 
   /// Returns the remaining capacity (which is to say, `self.capacity() - self.len()`) of the
   /// StaticVec.
+  ///
+  /// Example usage:
+  /// ```
+  /// # use staticvec::*;
+  /// let mut vec = StaticVec::<i32, 100>::new();
+  /// vec.push(1);
+  /// assert_eq!(vec.remaining_capacity(), 99);
+  /// ```
   #[inline(always)]
   pub const fn remaining_capacity(&self) -> usize {
     N - self.length
@@ -235,6 +247,19 @@ impl<T, const N: usize> StaticVec<T, N> {
   /// Returns the total size of the inhabited part of the StaticVec (which may be zero if it has a
   /// length of zero or contains ZSTs) in bytes. Specifically, the return value of this function
   /// amounts to a calculation of `size_of::<T>() * self.length`.
+  ///
+  /// Example usage:
+  /// ```
+  /// # use staticvec::*;
+  /// let x = StaticVec::<u8, 8>::from([1, 2, 3, 4, 5, 6, 7, 8]);
+  /// assert_eq!(x.size_in_bytes(), 8);
+  /// let y = StaticVec::<u16, 8>::from([1, 2, 3, 4, 5, 6, 7, 8]);
+  /// assert_eq!(y.size_in_bytes(), 16);
+  /// let z = StaticVec::<u32, 8>::from([1, 2, 3, 4, 5, 6, 7, 8]);
+  /// assert_eq!(z.size_in_bytes(), 32);
+  /// let w = StaticVec::<u64, 8>::from([1, 2, 3, 4, 5, 6, 7, 8]);
+  /// assert_eq!(w.size_in_bytes(), 64);
+  /// ```
   #[inline(always)]
   pub const fn size_in_bytes(&self) -> usize {
     intrinsics::size_of::<T>() * self.length
